/* Import adwaita theme... */
@import url('../../Adwaita/gtk-3.0/gtk.css');

/* ... and override its colors */
@define-color theme_base_color #9a9a9a;
@define-color theme_text_color #666;

@define-color theme_bg_color #9a9a9a;
@define-color theme_fg_color #666;

@define-color theme_selected_bg_color #8c8c80;
@define-color theme_selected_fg_color #666;

@define-color theme_tooltip_bg_color @theme_bg_color;
@define-color theme_tooltip_fg_color @theme_fg_color;

@define-color insensitive_bg_color #8c8c8c;
@define-color insensitive_fg_color #ccc;

@define-color trough_bg_color_a #8c8c80;
@define-color trough_bg_color_b #8c8c80;

@define-color button_border #61615a;
@define-color focused_entry_border #61615a;
@define-color frame_color #61615a;
@define-color highlighted_border #61615a;
@define-color notebook_border #61615a;

@define-color menu_fg_color #666;

@define-color keyboard_focus_color shade (@theme_fg_color, 0.9);

@define-color active_trough_bg_color_a shade (#8c8c80, 1.1);
@define-color active_trough_bg_color_b shade (#8c8c80, 1.15);

@define-color selected_row_bg_color_a #8c8c80;
@define-color selected_row_bg_color_b shade (#8c8c80, 0.9);


/*

@define-color link_color #4a90d9;
@define-color inactive_frame_color #c7ccc1;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

*/