/* dark colormap */

@define-color theme_base_color #333333;
@define-color theme_text_color #ddddde;
@define-color theme_bg_color #222222;
@define-color theme_fg_color @theme_text_color;
@define-color theme_selected_bg_color #f57900;
@define-color theme_selected_fg_color #ffffff;

@define-color menu_bg_color shade (@theme_bg_color, 0.4);
@define-color menu_fg_color #ffffff;

@define-color menu_combobox_border darker (@theme_selected_bg_color);

@define-color theme_tooltip_bg_color #000000;
@define-color theme_tooltip_fg_color #eeeeee;

@define-color button_gradient_color_a #363636;
@define-color button_gradient_color_b #222222;
@define-color button_border #111111;

@define-color button_active_gradient_color_a #000000;
@define-color button_active_gradient_color_b shade (@button_active_gradient_color_a, 0.93);

@define-color button_hover_gradient_color_a shade (@button_gradient_color_a, 1.07);
@define-color button_hover_gradient_color_b @theme_base_color;

@define-color insensitive_bg_color #0b0b0d;
@define-color insensitive_fg_color #585458;
@define-color insensitive_border_color shade (@internal_element_color, 0.70);

@define-color inactive_frame_color shade (@theme_bg_color, 1.19);

@define-color notebook_border #111111;
@define-color notebook_active_tab_border alpha (@theme_selected_bg_color, 1.0);
@define-color notebook_selected_tab_color alpha (@theme_selected_bg_color, 0.75);

@define-color notebook_tab_gradient_a shade (@button_gradient_color_a, 0.8);
@define-color notebook_tab_gradient_b shade (@button_gradient_color_b, 0.8);

@define-color switch_slider_color #111113;
@define-color switch_slider_border #a5b8cc;

@define-color highlighted_border @button_border;
@define-color internal_element_color #77757a;

@define-color progressbar_background_a shade(#e06a00, 1.30);
@define-color progressbar_background_b shade(#e06a00, 1.10);
@define-color progressbar_border alpha (@theme_fg_color, 0.60);
@define-color progressbar_pattern #000000;

@define-color focused_entry_border @theme_selected_bg_color;
@define-color focused_entry_inset alpha (@theme_selected_bg_color, 0.50);

@define-color toolbar_gradient_base #080808;
@define-color toolbar_gradient_step1 #0a0a0a;
@define-color toolbar_gradient_step2 #111111;
@define-color toolbar_gradient_final #151515;

@define-color toolbar_active_button_color #222222;

@define-color expander_row_selected_color alpha (@theme_base_color, 0.60);

@define-color menu_controls_color #aaa8ac;

@define-color keyboard_focus_border_a alpha (@theme_fg_color, 0.30);
@define-color keyboard_focus_border_b alpha (@theme_fg_color, 0.10);

@define-color trough_bg_color_a #000000;
@define-color trough_bg_color_b #111111;

@define-color frame_color #756a7f;

@define-color active_switch_bg_color_a shade (@theme_selected_bg_color, 0.85);
@define-color active_switch_bg_color_b @theme_selected_bg_color;

@define-color scale_fill shade (@insensitive_border_color, 0.90);
@define-color scale_border_a shade (@internal_element_color, 0.90);
@define-color scale_border_b shade (@internal_element_color, 0.65);

/* FIXME: needs dark colors from here */
@define-color link_color #4a90d9;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #4e9a06;

@define-color info_fg_color rgb (181, 171, 156);
@define-color info_bg_color rgb (252, 252, 189);
@define-color warning_fg_color rgb (173, 120, 41);
@define-color warning_bg_color rgb (250, 173, 61);
@define-color question_fg_color rgb (97, 122, 214);
@define-color question_bg_color rgb (138, 173, 212);
@define-color error_fg_color rgb (166, 38, 38);
@define-color error_bg_color rgb (237, 54, 54);

@define-color os_chrome_bg_color black;
@define-color os_chrome_fg_color #ccc;
@define-color os_chrome_selected_bg_color #333;
@define-color os_chrome_selected_fg_color white;

@define-color chrome_bg_color #1e1a17;
@define-color chrome_fg_color #fff;

@define-color scale_progress_fill #2c85e2;
@define-color scale_progress_border #1864b2;
@define-color scale_progress_border_b #3e90e5;

@import url("gtk-widgets-assets-dark.css");
@import url("gtk-widgets.css");
